==> filemv0.422.zip: source/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by myfilemv.rc
//
#define ID_savehost                     3
#define ID_loadhost                     4
#define ID_delhost                      5
#define ID_set_logon                    6
#define IDR_MENU1                       101
#define IDI_ICON1                       108
#define IDC_ID                          1000
#define IDC_PASSWORD                    1001
#define IDC_FTPADDRESS                  1002
#define IDC_BASEDIR                     1003
#define IDC_LOCALFILE                   1004
#define IDC_LOCALDIR                    1004
#define IDC_FNAME                       1005
#define IDC_MEMO                        1005
#define IDC_LIST1                       1006
#define IDC_EDIT1                       1007
#define IDC_sessionname                 1008
#define IDC_NAMELIST                    1009
#define IDC_CONNECT                     1010
#define IDC_STATIC1                     1012
#define IDC_STATIC2                     1014
#define IDM_END                         40001
#define IDM_CONNECT                     40002
#define IDM_DOWNLOAD                    40003
#define IDM_DISCONNECT                  40004
#define IDM_ACCOUNT                     40005
#define IDM_GETHOST                     40006
#define IDM_LOCALDRIVE                  40007
#define IDM_UPLOAD                      40008
#define IDM_CREATEDIR                   40009
#define IDM_DELFILE                     40010
#define IDM_UPDIRFTP                    40011
#define IDM_REMOVEDIR                   40012
#define IDM_UPDIRLOCAL                  40013
#define ID_MENUITEM40014                40014
#define IDM_EDIT                        40015
#define IDM_EDIT_INIT                   40016
#define IDM_OPEN_CUR                    40017
#define IDM_OPEN_INI                    40018
#define IDM_change_mode                 40019
#define IDM_changeb_mode                40022
#define IDM_change_mode_sw              40024
#define IDM_SAVE_DIRLOCAL               40025
#define IDM_LOAD_DIRLOCAL               40026
#define IDM_R_DIRLOCAL                  40027
#define IDM_LOCAL_CREATEDIR             40028
#define IDM_RENAME                      40029
#define IDM_RENAME_REMOTE               40030
#define IDM_R_DIRREMOTE                 40031
#define IDM_DELFILELOCAL                40032
#define IDM_REMOVEDIR_LOCAL             40033
#define IDM_AUTO                        40034
#define IDM_AUTOFILE_EDIT               40035
#define ID_MENUITEM40036                40036
#define IDM_OVERWRITE                   40037
#define IDM_WINDOW_ALL                  40038
#define IDM_WINDOW_EDIT                 40039
#define IDM_WINDOW_LIST                 40040
#define IDM_WINMODE                     40041
#define IDM_CHECK_CDIR                  40042
#define IDM_AUTOFILE_FILTER             40043
#define IDM_LOCAL_CREATE_FILE           40044
#define IDM_NEW_FILE                    40045
#define IDM_CHECK_VOL                   40046
#define IDM_UPLOAD_CUT                  40047
#define IDM_RELOAD_BOTH                 40048
#define IDM_SAVE_WINS                   40049
#define IDM_EXCHANGE                    40051
#define IDM_HIS_FORWARD                 40052
#define IDM_HIS_BACKWARD                40053
#define IDM_RENAME_2                    40054
#define IDM_COPY                        40055
#define IDM_ROOTDIR                     40056
#define IDM_SameDir                     40057
#define IDM_SSameDir                    40058
#define IDM_HERE_CUT                    40059
#define IDM_LISTL_WIDTH_1               40060
#define IDM_LISTL_WIDTH_2               40061
#define IDM_LISTL_WIDTH_3               40062
#define IDM_LISTL_ONLY                  40063
#define IDM_LISTR_ONLY                  40064
#define IDM_FIND                        40068
#define IDM_FIND2                       40069
#define IDM_COM                         40070
#define IDM_COMPARE                     40071
#define IDM_REV_SELECT                  40072
#define IDM_FIND_MORE                   40073
#define IDM_COM_NUM                     40074
#define IDM_UP_BUTTON                   40075
#define IDM_SORT1                       40076
#define IDM_SORT2                       40077
#define IDM_SORT3                       40078
#define IDM_SORT4                       40079
#define IDM_SORT5                       40080
#define IDM_EXT_SETCOLOR                40081
#define IDM_EXT_SETCOLOR_THIS           40082
#define IDM_COLOR_REV                   40083
#define IDM_WINDOW_MAX                  40084
#define IDM_WINDOW_INI                  40085
#define IDM_WINDOW_SMALLER              40086
#define IDM_WINDOW_BIGGER               40087
#define IDM_DEL_MENU                    40088
#define IDM_ZIP                         40089
#define IDM_SAVE_WINS_HOME              40090
#define IDM_LOAD_WINS_HOME              40091
#define IDM_COPY_HERE                   40092
#define IDM_LZH                         40093
#define IDM_OPEN_KEY_FILE               40094
#define IDM_UnLZH                       40095
#define IDM_PicOrgDown                  40096
#define IDM_PicOrgUp                    40097
#define IDM_PicOrgRight                 40098
#define IDM_PicOrgLeft                  40099
#define IDM_PicRateUp                   40100
#define IDM_PicRateDown                 40101
#define IDM_PicRateReset                40102
#define IDM_PicReset                    40103
#define IDM_mp3play                     40104
#define IDM_HIS_BackNoReload            40105
#define IDM_HIS_ForwNoReload            40106
#define IDM_DirEDIT_SW                  40107
#define IDM_Videoplay                   40108
#define IDM_TitleBar_SW                 40109
#define IDM_CompareSize                 40110
#define IDM_CompareSizeDate             40111
#define IDM_his_R                       40112
#define IDM_his_L                       40113
#define IDM_Set_Mainmenu_Pop            40114
#define IDM_CMD_BASE                    44000
#define IDM_CMD1                        44001
#define IDM_CMD2                        44002
#define IDM_CMD3                        44003
#define IDM_CMD_MAX                     44400
#define sessionIDBASE                   45000
#define localdirIDBASE                  46000
#define remotedirIDBASE                 47000
#define bothdirIDBASE                   48000
#define sendIDBASE                      49000
#define findIDBASE                      50000

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        111
#define _APS_NEXT_COMMAND_VALUE         40115
#define _APS_NEXT_CONTROL_VALUE         1015
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> filemv0.464.zip: source/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by myfilemv.rc
//
#define ID_savehost                     3
#define ID_loadhost                     4
#define ID_delhost                      5
#define ID_set_logon                    6
#define IDR_MENU1                       101
#define IDI_ICON1                       108
#define IDC_ID                          1000
#define IDC_PASSWORD                    1001
#define IDC_FTPADDRESS                  1002
#define IDC_BASEDIR                     1003
#define IDC_LOCALFILE                   1004
#define IDC_LOCALDIR                    1004
#define IDC_FNAME                       1005
#define IDC_MEMO                        1005
#define IDC_LIST1                       1006
#define IDC_EDIT1                       1007
#define IDC_sessionname                 1008
#define IDC_NAMELIST                    1009
#define IDC_CONNECT                     1010
#define IDC_STATIC1                     1012
#define IDC_STATIC2                     1014
#define IDM_END                         40001
#define IDM_CONNECT                     40002
#define IDM_DOWNLOAD                    40003
#define IDM_DISCONNECT                  40004
#define IDM_ACCOUNT                     40005
#define IDM_GETHOST                     40006
#define IDM_LOCALDRIVE                  40007
#define IDM_UPLOAD                      40008
#define IDM_CREATEDIR                   40009
#define IDM_DELFILE                     40010
#define IDM_UPDIRFTP                    40011
#define IDM_REMOVEDIR                   40012
#define IDM_UPDIRLOCAL                  40013
#define ID_MENUITEM40014                40014
#define IDM_EDIT                        40015
#define IDM_EDIT_INIT                   40016
#define IDM_OPEN_CUR                    40017
#define IDM_OPEN_INI                    40018
#define IDM_change_mode                 40019
#define IDM_changeb_mode                40022
#define IDM_change_mode_sw              40024
#define IDM_SAVE_DIRLOCAL               40025
#define IDM_LOAD_DIRLOCAL               40026
#define IDM_R_DIRLOCAL                  40027
#define IDM_LOCAL_CREATEDIR             40028
#define IDM_RENAME                      40029
#define IDM_RENAME_REMOTE               40030
#define IDM_R_DIRREMOTE                 40031
#define IDM_DELFILELOCAL                40032
#define IDM_REMOVEDIR_LOCAL             40033
#define IDM_AUTO                        40034
#define IDM_AUTOFILE_EDIT               40035
#define ID_MENUITEM40036                40036
#define IDM_OVERWRITE                   40037
#define IDM_WINDOW_ALL                  40038
#define IDM_WINDOW_EDIT                 40039
#define IDM_WINDOW_LIST                 40040
#define IDM_WINMODE                     40041
#define IDM_CHECK_CDIR                  40042
#define IDM_AUTOFILE_FILTER             40043
#define IDM_LOCAL_CREATE_FILE           40044
#define IDM_NEW_FILE                    40045
#define IDM_CHECK_VOL                   40046
#define IDM_UPLOAD_CUT                  40047
#define IDM_RELOAD_BOTH                 40048
#define IDM_SAVE_WINS                   40049
#define IDM_EXCHANGE                    40051
#define IDM_HIS_FORWARD                 40052
#define IDM_HIS_BACKWARD                40053
#define IDM_RENAME_2                    40054
#define IDM_COPY                        40055
#define IDM_ROOTDIR                     40056
#define IDM_SameDir                     40057
#define IDM_SSameDir                    40058
#define IDM_HERE_CUT                    40059
#define IDM_LISTL_WIDTH_1               40060
#define IDM_LISTL_WIDTH_2               40061
#define IDM_LISTL_WIDTH_3               40062
#define IDM_LISTL_ONLY                  40063
#define IDM_LISTR_ONLY                  40064
#define IDM_FIND                        40068
#define IDM_FIND2                       40069
#define IDM_COM                         40070
#define IDM_COMPARE                     40071
#define IDM_REV_SELECT                  40072
#define IDM_FIND_MORE                   40073
#define IDM_COM_NUM                     40074
#define IDM_UP_BUTTON                   40075
#define IDM_SORT1                       40076
#define IDM_SORT2                       40077
#define IDM_SORT3                       40078
#define IDM_SORT4                       40079
#define IDM_SORT5                       40080
#define IDM_EXT_SETCOLOR                40081
#define IDM_EXT_SETCOLOR_THIS           40082
#define IDM_COLOR_REV                   40083
#define IDM_WINDOW_MAX                  40084
#define IDM_WINDOW_INI                  40085
#define IDM_WINDOW_SMALLER              40086
#define IDM_WINDOW_BIGGER               40087
#define IDM_DEL_MENU                    40088
#define IDM_ZIP                         40089
#define IDM_SAVE_WINS_HOME              40090
#define IDM_LOAD_WINS_HOME              40091
#define IDM_COPY_HERE                   40092
#define IDM_LZH                         40093
#define IDM_OPEN_KEY_FILE               40094
#define IDM_UnLZH                       40095
#define IDM_PicOrgDown                  40096
#define IDM_PicOrgUp                    40097
#define IDM_PicOrgRight                 40098
#define IDM_PicOrgLeft                  40099
#define IDM_PicRateUp                   40100
#define IDM_PicRateDown                 40101
#define IDM_PicRateReset                40102
#define IDM_PicReset                    40103
#define IDM_mp3play                     40104
#define IDM_HIS_BackNoReload            40105
#define IDM_HIS_ForwNoReload            40106
#define IDM_DirEDIT_SW                  40107
#define IDM_Videoplay                   40108
#define IDM_TitleBar_SW                 40109
#define IDM_CompareSize                 40110
#define IDM_CompareSizeDate             40111
#define IDM_his_R                       40112
#define IDM_his_L                       40113
#define IDM_Set_Mainmenu_Pop            40114
#define IDM_ENTER                       40115
#define IDM_Set_CtrlKEY                 40116
#define IDM_mouseG                      40117
#define IDM_CMD_BASE                    44000
#define IDM_CMD1                        44001
#define IDM_CMD2                        44002
#define IDM_CMD3                        44003
#define IDM_CMD_MAX                     44400
#define sessionIDBASE                   45000
#define localdirIDBASE                  46000
#define remotedirIDBASE                 47000
#define bothdirIDBASE                   48000
#define sendIDBASE                      49000
#define findIDBASE                      50000

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        111
#define _APS_NEXT_COMMAND_VALUE         40118
#define _APS_NEXT_CONTROL_VALUE         1015
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
